---
languages:
  - en
  - cs
---
# Služba RBD

Rados Block Device **RBD** je blokové zařízení, které si můžete připojit do vaší infrastruktury. Připojení je nutné provést pomocí linuxového stroje (připojení RBD do Windows není v současné době provozně stabilní, proto jej nedoporučujeme). Následně si můžete připojené blokové zařízení reexportovat kamkoliv v rámci vašich systémů (samba remount do vaší sítě). RBD je vhodné zejména pro použití v centralizovaných zálohovacích systémech. RBD je velmi úzce specializovaná služba, která vyžaduje na straně uživatele širší zkušenosti se správou linuxových zařízení. Služba je určena řádově pro větší objemy dat - vyšší stovky TB. Blokové zařízení je možné rovněž na vaší straně opatřit šifrováním (client side) pomocí LUKS. Šifrování na straně klienta rovněž znamená, že přenos dat po síti je šifrován a v případě odposlechnutí během přenosu není možné data dešifrovat.

!!! warning
    Připojení RBD je možné pouze z dedikovaných IPv4 adres, které jsou povoleny na firewallu. Pokud stroj, na který chcete připojit RBD, má pouze IPv6 adresu, tak **NE**bude RBD možné připojit a budete muset využít službu S3. RBD obraz je možné následně připojit pouze na jednom zařízení, není možné, aby si každý z vašich uživatelů připojil stejné RBD na svoji pracovní stanici - za předpokladu, že RBD není použito pro clusterovaný file systém. Použití clusterovaných filesystemů nad RBD je potřeba nejdříve konzultovat s podporou Datových úložišť CESNET.

???+ note "Jak získám službu RBD?"
    Pro získání služby RBD prosím kontaktujte náš support:
    `support@cesnet.cz`

----
## Základní případy užití služby RBD
V následujících sekcích naleznete základní případy užití týkající se služby RBD.

### Zálohování velkých data setů vyžadující lokální filesystém
Pokud máte centralizovaný zálohovací systém (sada skriptů, bacula, BackupPC…) vyžadující lokální filesystém, pak vám doporučujeme použití [služby RBD](rbd-setup.md), viz níže. RBD obraz je možné připojit přímo ke stroji, kde běží centrální zálohovací systém, jako blokové zařízení. RBD je možné opatřit snapshoty viz, popis služeb, jako ochranu proti nechtěnému přepsání anebo ransomware útoku.

![](rbd-service-screenshots/central_backup.png){ style="display: block; margin: 0 auto" }

### Centrální share pro vnitřní potřeby instituce
Pokud ukládáte živá data a potřebujete na úložiště pouštět jednotlivé uživatele, pak můžete využít [službu RBD](rbd-setup.md), kterou si připojíte k vám do infrastruktury pomocí linuxového stroje. Na připojeném blokovém zařízení si můžete udělat souborový systém, případně jej opatřit šifrováním a dále je reexportovat dovnitř vaší infrastruktury například pomocí samba, NFS, ftp, ssh, aj. (možno i formou kontejnerů zajišťujících distribuci protokolů do vaší interní sítě). Šifrování na straně klienta rovněž znamená, že přenos dat po síti je šifrován a v případě odposlechnutí během přenosu není možné data dešifrovat. Výhodou je, že si můžete vytvářet skupiny a spravovat práva zcela dle vašich preferencí, případně použít vaši lokální databázi uživatelů a skupin. Blokové zařízení RBD je dále možné opatřit snapshoty na úrovni RBD, tudíž pokud dojde k nechtěnému odmazání dat je možné se vrátit například ke snapshotu z předchozího dne.

![](rbd-service-screenshots/shared_distribution.png){ style="display: block; margin: 0 auto" }

## Jak je řešena redundance dat - replicated vs erasure coding?
Níže jsou popsány druhy konfigurace služby RBD, které řeší redundaci dat nad úložným poolem. Služba RBD může být vybavena **replicated** nebo **erasure code (EC)** redundancí a dále **synchronní nebo asynchronní geografickou replikou**

### Replicated
Vaše data jsou na úložišti uložena ve třech kopiích. V případě poškození dat v jedné kopi jsou původní data stále čitelná v nepoškozené formě a na pozadí dojde k obnově poškozených dat. Použití služby s příznakem replicated rovněž umožňuje rychlejší čtení, protože je možné číst ze všech replik najednou. Použití služby s příznakem replicated snižuje rychlost zápisu, protože operace zápisu čeká na potvrzení zápisu ze všech třech replik. Naopak čtení je rzchlejší, peorože dochází ke čtení ze všech replik současně.


???+ note "Vhodné pro?"
    Vhodné pro menší objemy živých dat s preferencí rychlostí čtení (ne příliš vhodná pro velké datvé objemy).

### Erasure Coding (EC)
Erasure coding (EC) je metoda ochrany dat, jedná se o obdobu dynamického RAID známého z diskových polí. Erasure coding (EC) je metoda, kde jsou data rozdělena na jednotlivé fragmenty, které jsou následně uloženy s určitou redundancí napříč datovým úložištěm. Pokud tedy dojde k selhání některých disků (nebo celého storage serveru), tak jsou data stále přístupná a na pozadí dojde k jejich obnovení. Není tedy možné, aby vaše data ležela na jednom disku, který se poškodí a vy o data přijdete. Tato technologie je vhodná pro živější data (rychlejší zápis), ktere nevyžadují časté čtení. Zároveň je tato technologie úspornější co do množství obsazeného místa.

???+ note "Vhodné pro?"
    Vhodné např. spíše pro ukládaní velkých datových objemů.

### RBD snapshoty
Na úrovni RBD (replikované/erasure coding) je možné použít snapshoty. Ovládání snapshotů se provádí z klientské strany. [RBD snapshotování](rbd-setup.md) je jedna z možností náhrady za `tape_tape` politiku v případě mirroringu snapshotu do jiné geografické lokality.
 
### Synchronní geografická replika
Synchronní geografická replika chrání před výpadkem datového centra. Synchronní geografická replika zhoršuje rychlost zápisu, protože systém čeká na úspěšné potvrzení zápisu na obou geografických lokacích. Pokud máte dojem, že potřebujete tuto službu, tak se nám ozvěte.

### Asynchronní geografická replika
Asynchronní geografická replika chrání částečně před výpadkem datového centra (může dojít ke ztrátě určitých dat mezi jednotlivými asynchronními synchronizacemi z důvodu časové prodlevy). U asynchronní geografické repliky je však čas v případě poškození dat (ransomware) zasáhnout a přerušit synchronizaci. Pokud máte dojem, že potřebujete tuto službu, tak se nám ozvěte.                                                                                                         
